@@ -61,7 +61,7 @@ sub next_line {
 
     $this->{IN_HEADER} = 1;
 
-  } elsif ($line =~ /^RCS file: (.+)/) {
+  } elsif ($line =~ /^RCS file: (\S+)/) {
     $this->{FILE_STATE}{rcs_filename} = $1;
 
     $this->{IN_HEADER} = 1;
@@ -71,7 +71,7 @@ sub next_line {
 
     $this->{IN_HEADER} = 1;
 
-  } elsif ($line =~ /^Index:\s*(.+)/) {
+  } elsif ($line =~ /^Index:\s*(\S+)/) {
     $this->_maybe_end_file();
 
     $this->{FILE_STATE}{filename} = $1;
@@ -86,7 +86,7 @@ sub next_line {
     $this->{IN_HEADER} = 1;
 
   # section parsing
-  } elsif ($line =~ /^@@\s*-(\d+),?(\d*)\s*\+(\d+),?(\d*)\s*(?:@@\s*(.*))?/) {
+  } elsif ($line =~ /^@@\s*-(\d+),?(\d*)\s*\+(\d+),?(\d*)/) {
     $this->{IN_HEADER} = 0;
 
     $this->_maybe_start_file();
@@ -95,9 +95,7 @@ sub next_line {
     $4 = 0 if !defined($4);
     $this->{SECTION_STATE} = { old_start => $1, old_lines => $2,
                                new_start => $3, new_lines => $4,
-                               func_info => $5,
-                               minus_lines => 0, plus_lines => 0,
-                             };
+                               minus_lines => 0, plus_lines => 0 };
 
   } elsif ($line =~ /^(\d+),?(\d*)([acd])(\d+),?(\d*)/) {
     # Non-universal diff.  Calculate as though it were universal.
@@ -154,7 +152,6 @@ sub next_line {
 
 sub start_lines {
   my $this = shift;
-  die "No target specified: call sends_data_to!" if !$this->{TARGET};
   delete $this->{FILE_STARTED};
   delete $this->{FILE_STATE};
   delete $this->{SECTION_STATE};
@@ -199,11 +196,6 @@ sub _maybe_end_file {
 sub _start_file {
   my $this = shift;
 
-  # Send start notification and set state
-  if (!$this->{FILE_STATE}) {
-    $this->{FILE_STATE} = { filename => "file_not_specified_in_diff" };
-  }
-
   # Send start notification and set state
   $this->{TARGET}->start_file($this->{FILE_STATE});
   $this->{FILE_STARTED} = 1;
